@@ -4,8 +4,7 @@
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
-"""
-A clone of iotop (http://guichaz.free.fr/iotop/) showing real time
+"""A clone of iotop (http://guichaz.free.fr/iotop/) showing real time
 disk I/O statistics.
 
 It works on Linux only (FreeBSD and macOS are missing support for IO
@@ -72,7 +71,7 @@ def poll(interval):
     """
     # first get a list of all processes and disk io counters
     procs = list(psutil.process_iter())
-    for p in procs[:]:
+    for p in procs.copy():
         try:
             p._before = p.io_counters()
         except psutil.Error:
@@ -84,7 +83,7 @@ def poll(interval):
     time.sleep(interval)
 
     # then retrieve the same info again
-    for p in procs[:]:
+    for p in procs.copy():
         with p.oneshot():
             try:
                 p._after = p.io_counters()
@@ -116,23 +115,26 @@ def poll(interval):
 def refresh_window(procs, disks_read, disks_write):
     """Print results on screen by using curses."""
     curses.endwin()
-    templ = "%-5s %-7s %11s %11s  %s"
+    templ = "{:<5} {:<7} {:>11} {:>11}  {}"
     win.erase()
 
-    disks_tot = "Total DISK READ: %s | Total DISK WRITE: %s" \
-                % (bytes2human(disks_read), bytes2human(disks_write))
+    disks_tot = "Total DISK READ: {} | Total DISK WRITE: {}".format(
+        bytes2human(disks_read),
+        bytes2human(disks_write),
+    )
     printl(disks_tot)
 
-    header = templ % ("PID", "USER", "DISK READ", "DISK WRITE", "COMMAND")
+    header = templ.format("PID", "USER", "DISK READ", "DISK WRITE", "COMMAND")
     printl(header, highlight=True)
 
     for p in procs:
-        line = templ % (
+        line = templ.format(
             p.pid,
             p._username[:7],
             bytes2human(p._read_per_sec),
             bytes2human(p._write_per_sec),
-            p._cmdline)
+            p._cmdline,
+        )
         try:
             printl(line)
         except curses.error:
@@ -143,7 +145,7 @@ def refresh_window(procs, disks_read, disks_write):
 def setup():
     curses.start_color()
     curses.use_default_colors()
-    for i in range(0, curses.COLORS):
+    for i in range(curses.COLORS):
         curses.init_pair(i + 1, i, -1)
     curses.endwin()
     win.nodelay(1)
